;; Generated package description from emacs-lisp-intro-nl.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "emacs-lisp-intro-nl" "0.0.20260315.201559" "ELisp intro manual in NL" 'nil :commit "764e13f75a580dc48d9cc08dd7188a75860e199d" :url "https://elpa.gnu.org/packages/emacs-lisp-intro-nl.html" :authors '(("Matto Fransen" . "matto@matto.nl")) :maintainer '("Matto Fransen" . "matto@matto.nl"))
